[PATCH] D61719: Add ".dword" directive

Bill Wendling via Phabricator via llvm-commits llvm-commits at lists.llvm.org
Wed May 8 23:34:05 PDT 2019


void created this revision.
void added a reviewer: t.p.northover.
Herald added subscribers: llvm-commits, javed.absar.
Herald added a project: LLVM.
void added a subscriber: nickdesaulniers.

The ".dword" directive is a synonym for ".xword" and is used in the Linux
kernel.


Repository:
  rL LLVM

https://reviews.llvm.org/D61719

Files:
  lib/Target/AArch64/AsmParser/AArch64AsmParser.cpp


Index: lib/Target/AArch64/AsmParser/AArch64AsmParser.cpp
===================================================================
--- lib/Target/AArch64/AsmParser/AArch64AsmParser.cpp
+++ lib/Target/AArch64/AsmParser/AArch64AsmParser.cpp
@@ -241,11 +241,13 @@
     if (S.getTargetStreamer() == nullptr)
       new AArch64TargetStreamer(S);
 
     // Alias .hword/.word/xword to the target-independent .2byte/.4byte/.8byte
     // directives as they have the same form and semantics:
     ///  ::= (.hword | .word | .xword ) [ expression (, expression)* ]
     Parser.addAliasForDirective(".hword", ".2byte");
     Parser.addAliasForDirective(".word", ".4byte");
+    Parser.addAliasForDirective(".dword", ".8byte");
     Parser.addAliasForDirective(".xword", ".8byte");
 
     // Initialize the set of available features.


-------------- next part --------------
@@ -241,11 +241,13 @@
       new AArch64TargetStreamer(S);
 
-    // Alias .hword/.word/xword to the target-independent .2byte/.4byte/.8byte
-    // directives as they have the same form and semantics:
-    ///  ::= (.hword | .word | .xword ) [ expression (, expression)* ]
+    // Alias .hword/.word/[dx]word to the target-independent
+    // .2byte/.4byte/.8byte directives as they have the same form and
+    // semantics:
+    ///  ::= (.hword | .word | .dword | .xword ) [ expression (, expression)* ]
     Parser.addAliasForDirective(".hword", ".2byte");
     Parser.addAliasForDirective(".word", ".4byte");
A non-text attachment was scrubbed...
Name: D61719.198766.patch
Type: text/x-patch
Size: 1050 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/llvm-commits/attachments/20190509/f44f2c82/attachment.bin>


More information about the llvm-commits mailing list